/***************************************************************************
                          globdefines.h  -  description
                             -------------------
    begin                : Fri Mar 28 2003
    copyright            : (C) 2003 by Harald Krippel
    email                : harald@the-develop.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   this program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

/**
  *@author Krippel Harald
  */

 #define QCAKEVERSION "QCake-Designer V0.7.0 [rev824]"

 #define MAX_FIRE_TRIS  200
 #define OBJ_OFF  -200000.0f
 #define MAX_PLAYER 10
 #define MAX_PLAYER_OBJ 10
 #define TIMER_INTERVAL 10
 #define DEFAULTSTARTID 4
